#
# spec file for package nss_ldap
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nss_ldap
Version:        265
Release:        lp151.4.3.1
Summary:        NSS LDAP Module
License:        LGPL-2.1+
Group:          Productivity/Networking/LDAP/Clients
Url:            http://www.padl.com/OSS/nss_ldap.html
Source:         %{name}-%{version}.tar.gz
Source1:        README.SUSE
Source2:        baselibs.conf
Source3:        ldap.conf
Patch0:         0000-nss_ldap.dif
Patch1:         0001-group-utf8.dif
Patch2:         0002-nss_ldap-ldapconn-leak-bug418.dif
Patch3:         0003-nss_ldap-getent-retry.dif
Patch4:         0004-nss_ldap-getent-skip-invalid-uidgidnumber.dif
# Upstream issue with glibc-2.16 http://bugzilla.padl.com/show_bug.cgi?id=445
Patch5:         0005-nss_ldap-265-glibc-2.16.patch
# Fix also issue with threads on glibc-2.16 http://bugzilla.padl.com/show_bug.cgi?id=446
Patch6:         0006-nss_ldap-265-pthread.patch
# SIGPIPE handling atfork
Patch7:         0007-bnc#842120.dif
# reverse ipv6 host lookups fail when ldap is used
Patch8:         0008-bnc#866763.dif
Patch9:         0009-fix-for-BUG-412-don-t-close-nested-contexts.patch
Patch10:        0010-initialize-context-in-_nss_ldap_getbyname.patch
Patch11:        0011-When-invoked-via-glibc-the-input-buffer-is-enlarged.patch
# PATCH-FIX-TO-UPSTREAM -- is not opensuse specific
Patch12:        reproducible.patch
Patch13:        nss_ldap-perl-5.26.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  db-devel
BuildRequires:  krb5-devel
BuildRequires:  libtool
BuildRequires:  openldap2-devel
Requires(pre):  %{_bindir}/grep
Requires(pre):  /bin/mktemp
Requires(pre):  coreutils
Requires(pre):  sed

%description
Nss_ldap is a glibc NSS module that allows X.500 and LDAP directory
servers to be used as a primary source of aliases, ethers, groups,
hosts, networks, protocol, users, RPCs, services, and shadow passwords
(instead of or in addition to using flat files or NIS).

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5
%patch6
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
cp -v %{SOURCE1} .

%build
autoreconf -fiv
export CPPFLAGS="-I/usr/include/sasl -DINET6"
%configure \
  --enable-rfc2307bis \
	--enable-paged-results \
  --enable-configurable-krb5-ccname-gssapi \
	--x-libraries=%{_prefix}/X11R6/%{_lib}
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_lib}
mkdir -p %{buildroot}%{_libdir}
install -m 755 nss_ldap.so %{buildroot}/%{_lib}/libnss_ldap.so.2
install -d 755 %{buildroot}/%{_sysconfdir}/
install -m 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/
make DESTDIR=%{buildroot} install-man

%pre
# If we have a /etc/ldap.conf.rpmsave, and no /etc/ldap.conf,
# backup the rpmsave file and use that later instead of our
# own version. This fixes the problem that the file was moved
# from pwdutils to nss_ldap and else the changes would go lost.
if [ ! -e %{_sysconfdir}/ldap.conf -a -f %{_sysconfdir}/ldap.conf.rpmsave ]; then
   cp -p %{_sysconfdir}/ldap.conf.rpmsave %{_sysconfdir}/...ldap.conf.pwdutils
fi

%post
/sbin/ldconfig
# If we backuped ldap.conf, move now the backup in place
test -f %{_sysconfdir}/...ldap.conf.pwdutils && mv %{_sysconfdir}/...ldap.conf.pwdutils %{_sysconfdir}/ldap.conf ||:

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/ldap.conf
%doc ANNOUNCE AUTHORS COPYING ChangeLog NEWS README README.SUSE nsswitch.ldap ldap.conf doc/README.paged
/%{_lib}/libnss_ldap.so.2
%{_mandir}/man5/nss_ldap.5*

%changelog
* Mon Nov 11 2019 William Brown <william.brown@suse.com>
- bsc#1154340 missing export caused INET6 to fail in nss_ldap
* Wed Mar 21 2018 varkoly@suse.com
- bsc#1081768 missing nss_ldap and pam_ldap packages (plus dependencies)
* Mon Oct  9 2017 dimstar@opensuse.org
- Add nss_ldap-perl-5.26.patch: Fix build with perl 5.26. $cwd is
  no longer part of @INC.
* Mon Jan 23 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Fri Aug 26 2016 hguo@suse.com
- Relabel patches:
    nss_ldap.dif -> 0000-nss_ldap.dif
    group-utf8.dif -> 0001-group-utf8.dif
    nss_ldap-ldapconn-leak-bug418.dif ->
    0002-nss_ldap-ldapconn-leak-bug418.dif
    nss_ldap-getent-retry.dif -> 0003-nss_ldap-getent-retry.dif
    nss_ldap-getent-skip-invalid-uidgidnumber.dif ->
    0004-nss_ldap-getent-skip-invalid-uidgidnumber.dif
    nss_ldap-265-glibc-2.16.patch -> 0005-nss_ldap-265-glibc-2.16.patch
    nss_ldap-265-pthread.patch -> 0006-nss_ldap-265-pthread.patch
    bnc#842120.dif -> 0007-bnc#842120.dif
    bnc#866763.dif -> 0008-bnc#866763.dif
- Add patches:
  * Resolve a connection management issue in oneshot operation mode &
    Fix bad variable initialisation (bsc#934444)
    0009-fix-for-BUG-412-don-t-close-nested-contexts.patch
    0010-initialize-context-in-_nss_ldap_getbyname.patch
  * Fix buffer management issue between glibc and LDAP (bsc#986858)
    0011-When-invoked-via-glibc-the-input-buffer-is-enlarged.patch
* Wed Sep  2 2015 mpluskal@suse.com
- Use %%configure macro
- Remove unrecognized configure options
  * --enable-schema-mapping,
  * --enable-xad
- Use url for source
- Update dependencies on autotools
- Use Requires(pre) in spec file
* Mon Nov  3 2014 dimstar@opensuse.org
- Call autoreconf -fiv in place of autoreconf: ensure that
  autoreconf is successful in newer versions too.
* Fri Aug 15 2014 kukuk@suse.de
- Save old ldap.conf from pwdutils to not lose ldap configuration
  [bnc#891585]
* Fri Aug  8 2014 varkoly@suse.com
- added bnc#842120.dif  bnc#866763.dif
- bnc#879368 - Bug in ldap_nss prevents Nomachine NX server to start
- bnc#866763 - reverse ipv6 host lookups fail when ldap is used
  * bnc#866763.dif
- bnc#842120 - nss_ldap crashes when running atfork() hooks
  * bnc#842120.dif
* Fri Aug  1 2014 varkoly@suse.com
- bnc#889015 - Package 'nss_ldap' contains 'SuSE' spelling in a filename and/or SPEC file
* Fri Mar 15 2013 rhafer@suse.com
- ldap.conf is now part of nss_ldap since pwdutils was dropped
  (bnc#809245)
- removed no longer needed %%post scriptlet
* Mon Jan 28 2013 tchvatal@suse.com
- Fix segfault when using with glibc-2.16 and linking with pthread.
  * adds patches:
    nss_ldap-265-glibc-2.16.patch (PADL-Bug#445)
    nss_ldap-265-pthread.patch (PADL-Bug#446)
* Thu Oct 18 2012 coolo@suse.com
- fix build with possix correctly set (added to nss_ldap.dif)
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Oct 28 2011 rhafer@suse.de
- Entries with invalid (or too large) uidNumber/gidNumber attributes
  could crash nss_ldap (bnc#726393)
* Mon Jan 17 2011 rhafer@suse.de
- A memory leak in nss_ldap could lead to processes (e.g. nscd)
  growing extremely large (bnc#659100, PADL-Bug#418)
- nss_ldap didn't try to reconnect properly when the LDAP
  connection was lost between two getXXent() calls
  (bnc#662752, PADL-Bug#215)
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Tue Dec 15 2009 rhafer@novell.com
- Update to nss_ldap-265. From the changelog:
  * fix for PADL-Bug#132: add versioning information to binary
  * fix for PADL-Bug#403: add AM_MAINTAINER_MODE
  * fix for PADL-Bug#388: bad LDAP query for ether lookups
  * fix for PADL-Bug#391: clarify bind timelimit defaults
    in ldap.conf
  * fix for PADL-Bug#392: call do_close() if ldap_result()
    or ldap_parse_result() fails (before returning
    NSS_UNAVAIL)
  * fix for PADL-Bug#409: deallocate context in
    _nss_ldap_ent_context_release() to avoid bad usage
  * fix for PADL-Bug#410: don't leak file descriptors in
    _nss_ldap_readconfig
* Thu Jun 25 2009 sbrabec@suse.cz
- Supplement glibc-32bit/glibc-64bit in baselibs.conf (bnc#354164).
* Tue May 19 2009 rhafer@novell.com
- updated to nss_ldap-264. From the changelog:
  * fix for PADL-Bug#378: MAP_H_ERRNO() should map NSS_TRYAGAIN
    to NETDB_INTERNAL not TRY_AGAIN
  * fix for PADL-Bug#379: ldaps:// URIs only work if "ssl on"
    is set
  * fix for PADL-Bug#248: nss_ldap exposes malformed entries to the
    system
  * fix for PADL-Bug#374: nss_ldap returns success from setnetgrent()
    when the requested netgroup doesn't exist
  * fix for PADL-Bug#376: getXXent() only returns NULL once before
    implicitly calling setXXent(), whereas other backends continue
    to return NULL
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 28 2008 rhafer@suse.de
- Only set default port when "port" directive is present in
  /etc/ldap.conf or when "ssl on" is set. (bnc#439449)
- Apply "tls_*" options when "ldaps" URI are used (bnc#439449)
* Thu Aug 28 2008 rhafer@suse.de
- Update to nss_ldap-262, fixes a minor bug in the default
  config file (PADL-Bug#371) and a build issue on Solaris
  (PADL-Bug#370)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Mar  4 2008 rhafer@suse.de
- Update to nss_ldap-260:
  * only set errno for NSS_TRYAGAIN (bnc#366587)
- removed obsolete sigset.dif patch
* Thu Nov  8 2007 rhafer@suse.de
- Fixed pre-requires
* Mon Oct 29 2007 rhafer@suse.de
- Update to nss_ldap-259
  * fix for BUG#348: fix memory leak
  * fix for BUG#349: nss_ldap crashes after START_TLS timeout
    (assertion failure in libldap)
  * fix for BUG#350: assertion failure in ldap_result (called
    from do_result())
  * fix for BUG#351: double ldap_msgfree()
* Thu Oct 18 2007 rhafer@suse.de
- Update to nss_ldap-258
  * fix for PADL-Bug#343: nss_srv_domain should take a domain
    not a record
  * fix for PADL-Bug#339: replacement code for Kerbeors
    SASL operations
  * fix for PADL-Bug#338: nss_ldap constructs LDAP URIs
    incorrectly
  * fix for PADL-Bug#337: configure fails to detect resolver
    functions
  * fix for PADL-Bug#332: --enable-schema-mapping incorrectly
    maps pw_change
  * fix for PADL-Bug#293: add nss_getgrent_skipmembers
    parameter to ldap.conf, if enabled will not request
    member attributes for group lookups, greatly increasing
    performance for large groups
* Fri Aug  3 2007 rhafer@suse.de
- Update to nss_ldap-257. (Just includes the fix for Bug #294456)
* Mon Jul 30 2007 rhafer@suse.de
- Ignore SIGPIPE in atfork-Handlers (Bug #294456)
- Removed *.so link
* Fri Jul  6 2007 rhafer@suse.de
- Fix URI generation when looking up LDAP Server via SRV records
- Update to nss_ldap-256
  * patch from Tomas Janousek <tjanouse@redhat.com> to check for
    pthread_once(); __pthread_once does not imply __pthread_atfork
    being non-NULL
  * fix for BUG#315: memory corruption/crash in initgroups parsing
* Mon Mar  5 2007 rhafer@suse.de
- Update to nss_ldap-255
  * fix for PADL-Bug#304: fd leak in do_close_no_unbind
  * patch from Adrian Bridgett <adrian@smop.co.uk>
    for Debian BUG#375533: Assertion failure in libnss-ldap
* Thu Mar  1 2007 rhafer@suse.de
- nss_ldap could crash when no host or uri is configured in
  /etc/ldap.conf or DNS (Bug #248594)
* Tue Jan 30 2007 rhafer@suse.de
- Apply the "port" directive correctly if present in ldap.conf
  (Bug #224879)
* Mon Jan 15 2007 rhafer@suse.de
- Update to nss_ldap-254
  * fix for BUG#292: array bounds check in ldap-network.c
  * fix for BUG#296: fix stack buffer optimization
  * fix for BUG#297: gethostbyname2 queried with AF_INET6 returns
    OK with IPv4 address
  * fix for Novell BUG#215911: crasher parsing nested groups
* Wed Oct 18 2006 rhafer@suse.de
- Update to nss_ldap-253. Fixes crasher if an empty buffer is
  passed to initgroups (glibc NSS only)
* Tue Aug 22 2006 rhafer@suse.de
- Update to nss_ldap-252. Most important changes:
  * fix regression in per-objectclass attribute mapping
  * don't use static _nss_ldap_no_members buffer,
    causes crash when nss_ldap is unloaded and memory
    is still referenced
  * fix for PADL-BUG#255: deadlock in initgroups
  * make objectClass a mappable attribute
* Mon Mar 13 2006 rhafer@suse.de
- Don't use static buffer for groups without members
  (Bugzilla: #157066)
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 26 2006 rhafer@suse.de
- retry at least one time if "bind_policy soft"
- better workaround for __pthread_once and pthread_atfork hacks
* Wed Jan 25 2006 rhafer@suse.de
- Update to nss_ldap-246 (Bugzilla: #145170)
* Thu Jan 19 2006 rhafer@suse.de
- add "bind_policy soft" to /etc/ldap.conf during update
  if no "bind_policy" is set explicitly (Bugzilla: #139578)
* Fri Jan 13 2006 rhafer@suse.de
- Fixed paged results. http://bugzilla.padl.com/show_bug.cgi?id=245
* Wed Jan 11 2006 rhafer@suse.de
- Update to nss_ldap-245
* Tue Jan 10 2006 rhafer@suse.de
- use pthread_atfork() instead of glibc-internal __pthread_once
- neededforbuild cleanup
* Thu Dec 22 2005 rhafer@suse.de
- Update to nss_ldap-244
- Fixed man-page it's "bind_policy" not "reconnect_policy"
* Wed Oct 12 2005 rhafer@suse.de
- Update to nss_ldap-243
* Tue Mar 29 2005 rhafer@suse.de
- Update to nss_ldap-238
* Mon Feb 21 2005 rhafer@suse.de
- Update to nss_ldap-234 (contains a better fix for Bug #50702)
* Mon Feb 14 2005 rhafer@suse.de
- Update to nss_ldap-233
- connect_on_init.dif: fixes Bug #50702
* Fri Jan 28 2005 rhafer@suse.de
- Update to nss_ldap-232
- Fixed path in README.SuSE
* Tue Jan 18 2005 rhafer@suse.de
- Update to nss_ldap 229
- added kerberos-devel-packages to neededforbuild and turned on
  configurable Kerberos V credentials cache name
* Thu Oct 14 2004 rhafer@suse.de
- Update to nss_ldap 226
- fixed README.SuSE
* Thu Feb 19 2004 kukuk@suse.de
- Increase the buffer for struct sockaddr to hold all data.
* Wed Feb 18 2004 kukuk@suse.de
- Add patch to fix seg.fault from Ralf Haferkamp
* Sat Feb 14 2004 kukuk@suse.de
- Update to nss_ldap 215
- Fix handling of UTF-8 group names [Bug #34549]
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Tue Sep  2 2003 sbrabec@suse.cz
- Turned on schema mapping, XAD support and paged results.
- Packaged more docs.
* Mon Jul 14 2003 sbrabec@suse.cz
- Changed path to ldap.conf to /etc (bug #27528).
* Mon Jun  9 2003 sbrabec@suse.cz
- Updated to version 207.
* Sat Feb 15 2003 kukuk@suse.de
- Update to 203.7. Includes netgroup support.
* Fri Feb 14 2003 kukuk@suse.de
- Fix seg.fault on x86-64 in gethost* functions
- Implement IPv6 support for gethost* functions
* Thu Feb 13 2003 kukuk@suse.de
- Enable IPv6 support (else we will leak file descriptors with IPv6
  addresses).
* Tue Nov  5 2002 sbrabec@suse.cz
- Update to version 203.
* Tue Oct 29 2002 sbrabec@suse.cz
- Update to version 202.
- Don't own /etc/openldap, required openldap2-client creates it.
* Thu Aug 29 2002 tcrhak@suse.cz
- fixed sigprocmask bug (bug #18236)
* Mon Aug 26 2002 rhafer@suse.de
- LDAP_FILT_MAXSIZ isn't defined in libldap anymore
* Tue Aug 13 2002 kukuk@suse.de
- Update to version 199 (glibc alias enumeration functions, DNS
  response parser)
* Sat Jul 27 2002 kukuk@suse.de
- Update to version 198 (fixes a potential buffer overflow in the
  DNS SRV code)
* Tue Jul 16 2002 kukuk@suse.de
- Update to version 197 (lot of "buffer to small" bug fixes)
* Sat Apr 27 2002 kukuk@suse.de
- Update to 187 (minor bug fixes)
* Mon Feb  4 2002 tcrhak@suse.cz
- update to 183
- used %%{_lib} and %%{_lidir} macros
* Fri Nov 23 2001 tcrhak@suse.cz
- update to version 174
* Tue Aug  7 2001 cihlar@suse.cz
- update to version 167
* Sat May 12 2001 schwab@suse.de
- Fix missing declarations.
- Add %%suse_update_config.
* Thu Apr 19 2001 kukuk@suse.de
- Do not enable ids-uid, it is broken
* Wed Apr 18 2001 pblaha@suse.cz
- back to /etc/openldap/ldap.conf
- update on version 150
- add URL
* Wed Mar 21 2001 ro@suse.de
- fixed neededforbuild again
* Fri Mar 16 2001 pblaha@suse.cz
- update on version 149
- add build root
* Thu Mar 15 2001 ro@suse.de
- fixed neededforbuild for openldap
* Wed Jan 31 2001 choeger@suse.de
- link against ldaplib2
* Mon Dec 11 2000 kukuk@suse.de
- Update to 123
* Sat Nov  4 2000 kukuk@suse.de
- Use ldaplib
* Thu Jun  1 2000 kukuk@suse.de
- Update to 110
* Mon Apr 10 2000 kukuk@suse.de
- Fix typo in path to config file
* Tue Feb 15 2000 kukuk@suse.de
- Update to version 105
* Tue Oct 12 1999 kukuk@suse.de
- Update to 87
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  9 1999 kukuk@suse.de
- Update to 85
* Mon Jul 12 1999 kukuk@suse.de
- Update to 81
- Add ldap.conf and README.SuSE to documentation
* Fri Jun 25 1999 kukuk@suse.de
- Update to 2.77
* Wed Jun  9 1999 kukuk@suse.de
- Update to 2.69
* Fri May  7 1999 kukuk@suse.de
- Initial version of nss_ldap 2.64
